package DBICNSTest::RSet::C;

use warnings;
use strict;

use base qw/DBIx::Class::ResultSet/;
1;
